import{s as o}from"./index.RuhrnD1v.js";const i={[o.ButtonLikeIconPosition.LEFT]:"left",[o.ButtonLikeIconPosition.RIGHT]:"right"};function s(t){return i[t??o.ButtonLikeIconPosition.LEFT]}export{s as m};
