import{j as e,T as s,P as b,g as c}from"./index.RuhrnD1v.js";import{b as m}from"./styled-components.CXqQ-NdV.js";function g({content:a,label:l,ariaLabel:o,placement:t=b.TOP_RIGHT,isLatex:i,markdownProps:r,onMouseEnterDelay:p,containerWidth:n}){return e(m,{children:e(s,{content:a,placement:t,isLatex:i,markdownProps:r,onMouseEnterDelay:p,containerWidth:n,ariaLabel:o??c(l)})})}export{g as W};
