import{r as e,E as o,_ as n,b8 as i,b9 as l}from"./index.RuhrnD1v.js";var s=e.forwardRef(function(r,t){var a={fill:"currentColor",xmlns:"http://www.w3.org/2000/svg"};return e.createElement(o,n({iconAttrs:a,iconVerticalAlign:"middle",iconViewBox:"0 0 24 24"},r,{ref:t}),e.createElement("path",{fill:"none",d:"M0 0h24v24H0V0z"}),e.createElement("path",{d:"M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12 19 6.41z"}))});s.displayName="Close";function u(r){if(Array.isArray(r))return i(r)}function c(r){if(typeof Symbol<"u"&&r[Symbol.iterator]!=null||r["@@iterator"]!=null)return Array.from(r)}function m(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function y(r){return u(r)||c(r)||l(r)||m()}export{s as C,y as _};
