import{r as e,E as n,_ as o}from"./index.RuhrnD1v.js";var c=e.forwardRef(function(t,r){var a={fill:"currentColor",xmlns:"http://www.w3.org/2000/svg"};return e.createElement(n,o({iconAttrs:a,iconVerticalAlign:"middle",iconViewBox:"0 0 24 24"},t,{ref:r}),e.createElement("path",{fill:"none",d:"M0 0h24v24H0V0z"}),e.createElement("path",{d:"M20 3H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h15c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm0 2v3H5V5h15zm-5 14h-5v-9h5v9zM5 10h3v9H5v-9zm12 9v-9h3v9h-3z"}))});c.displayName="TableChart";export{c as T};
