import{n as e}from"./numbro.B9_PXfzp.js";import{s as u}from"./sprintfjs.DSsuEWyc.js";import{e as m,n as s}from"./index.RuhrnD1v.js";function o(t){if(t===0||Math.abs(t)>=1e-4)return 4;const n=t.toExponential().split("e");return Math.abs(parseInt(n[1],10))}function i(t,r={}){const n=navigator.languages;try{return new Intl.NumberFormat(n,r).format(t)}catch(a){if(a instanceof RangeError)return new Intl.NumberFormat(void 0,r).format(t);throw a}}function p(t,r,n){return Number.isNaN(t)||!Number.isFinite(t)?"":m(r)||r===""?s(n)?(n===0&&(t=Math.round(t)),e(t).format({thousandSeparated:!1,mantissa:n,trimMantissa:!1})):e(t).format({thousandSeparated:!1,mantissa:o(t),trimMantissa:!0}):r==="plain"?e(t).format({thousandSeparated:!1,mantissa:20,trimMantissa:!0}):r==="localized"?i(t,{minimumFractionDigits:n??void 0,maximumFractionDigits:n??void 0}):r==="percent"?i(t,{style:"percent",minimumFractionDigits:s(n)?Math.max(n-2,0):0,maximumFractionDigits:s(n)?Math.max(n-2,0):2}):r==="dollar"?i(t,{style:"currency",currency:"USD",currencyDisplay:"narrowSymbol",minimumFractionDigits:n??2,maximumFractionDigits:n??2}):r==="euro"?i(t,{style:"currency",currency:"EUR",currencyDisplay:"narrowSymbol",minimumFractionDigits:n??2,maximumFractionDigits:n??2}):r==="yen"?i(t,{style:"currency",currency:"JPY",currencyDisplay:"narrowSymbol",minimumFractionDigits:n??0,maximumFractionDigits:n??0}):["compact","scientific","engineering"].includes(r)?i(t,{notation:r}):r==="accounting"?e(t).format({thousandSeparated:!0,negative:"parenthesis",mantissa:n??2,trimMantissa:!1}):r==="bytes"?i(t,{notation:"compact",style:"unit",unit:"byte",unitDisplay:"narrow",maximumFractionDigits:1}).replace("BB","GB"):u(r,t)}function y(t){if(t.trim()==="")return!1;const r=Number(t);return!Number.isNaN(r)&&Number.isFinite(r)}export{p as f,y as i};
