import{r as g,j as t,f as a,aa as d}from"./index.RuhrnD1v.js";import{S as l}from"./styled-components.BjCveN31.js";import{S as p}from"./select.C3diGM4n.js";function f(r){const i=g.forwardRef(({children:e,$isHighlighted:s,...o},n)=>t(r,{ref:n,...o,children:t(l,{$isHighlighted:s,children:e})}));return i.displayName=`HighlightListItem(${r.displayName||r.name||"Component"})`,i}const u=a("div",{target:"e1bzcuw60"})({position:"absolute",top:"50%",right:"2.05em"}),y=a(p,{shouldForwardProp:d,target:"e1bzcuw61"})(({theme:r})=>({position:"relative",display:"flex",alignItems:"center",padding:r.spacing.none,margin:r.spacing.none,height:r.sizes.dropdownItemHeight,marginLeft:r.sizes.tagMarginInsideBorder,marginRight:`max(0px, calc(${r.sizes.tagMarginInsideBorder} - var(--scrollbar-gutter-size, 0px)))`,background:"transparent",fontWeight:r.fontWeights.normal}));export{y as S,u as a,f as c};
