import{f as e,r as a,h as t,j as r,k as o}from"./index.RuhrnD1v.js";import{P as l}from"./ProgressBar.CMnb-7c9.js";const i=e("div",{target:"e1jwj65h0"})(({theme:s})=>({paddingBottom:s.spacing.sm,lineHeight:"normal"}));function d({element:s}){return t("div",{className:"stProgress","data-testid":"stProgress",children:[r(i,{children:r(o,{source:s.text,allowHTML:!1,isLabel:!0})}),r(l,{value:s.value})]})}const m=a.memo(d);export{m as default};
