import{j as e,T as s,P as c,g as m}from"./index.RuhrnD1v.js";import{S as I}from"./styled-components.CXqQ-NdV.js";function d({content:a,label:l,ariaLabel:i,placement:o=c.TOP_RIGHT,isLatex:t,markdownProps:n,onMouseEnterDelay:r,containerWidth:p}){return e(I,{children:e(s,{content:a,placement:o,isLatex:t,markdownProps:n,onMouseEnterDelay:r,containerWidth:p,ariaLabel:i??m(l)})})}export{d as W};
