import{f as s,r as t,n as i,j as d,e}from"./index.RuhrnD1v.js";import{D as c,a as l}from"./IFrameUtil.DefezniK.js";const f=s("iframe",{target:"eu9re3w0"})(({theme:o,disableScrolling:r})=>({width:"100%",height:"100%",colorScheme:"normal",border:"none",padding:o.spacing.none,margin:o.spacing.none,overflow:r?"hidden":void 0}));function n(o){return e(o)||o===""?void 0:o}function m({element:o}){const r=n(o.src),a=i(r)?void 0:n(o.srcdoc);return d(f,{className:"stIFrame","data-testid":"stIFrame",allow:l,disableScrolling:!o.scrolling,src:r,srcDoc:a,scrolling:o.scrolling?"auto":"no",sandbox:c,title:"st.iframe",tabIndex:o.tabIndex??void 0})}const F=t.memo(m);export{F as default};
