import{r as s,ap as d,aq as l,j as a,F as x,f,z as C,N as g}from"./index.RuhrnD1v.js";const M=({children:t})=>{const e=s.useContext(d)?.();return e?l.createPortal(t,e):a(x,{children:t})},P=f("div",{target:"e1smm6vf0"})({"@media print":{display:"none"}}),u=({className:t,scriptRunId:e,numParticles:o,numParticleTypes:r,ParticleComponent:n})=>{const{resourceCrossOriginMode:i}=s.useContext(C),c=s.useMemo(()=>g(o).map(()=>Math.floor(Math.random()*r)),[o,r]);return a(P,{className:t,"data-testid":t,children:c.map((m,p)=>a(n,{particleType:m,resourceCrossOriginMode:i},e+p))})},y=s.memo(u);export{y as P,M as R};
