import{r as f,a6 as b,a7 as g,a8 as m,a9 as h}from"./index.RuhrnD1v.js";var _=["title","size","color","overrides"];function c(){return c=Object.assign?Object.assign.bind():function(e){for(var r=1;r<arguments.length;r++){var t=arguments[r];for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])}return e},c.apply(this,arguments)}function O(e,r){if(e==null)return{};var t=A(e,r),n,a;if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(e);for(a=0;a<o.length;a++)n=o[a],!(r.indexOf(n)>=0)&&Object.prototype.propertyIsEnumerable.call(e,n)&&(t[n]=e[n])}return t}function A(e,r){if(e==null)return{};var t={},n=Object.keys(e),a,o;for(o=0;o<n.length;o++)a=n[o],!(r.indexOf(a)>=0)&&(t[a]=e[a]);return t}function S(e,r){return E(e)||I(e,r)||j(e,r)||C()}function C(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function j(e,r){if(e){if(typeof e=="string")return d(e,r);var t=Object.prototype.toString.call(e).slice(8,-1);if(t==="Object"&&e.constructor&&(t=e.constructor.name),t==="Map"||t==="Set")return Array.from(e);if(t==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t))return d(e,r)}}function d(e,r){(r==null||r>e.length)&&(r=e.length);for(var t=0,n=new Array(r);t<r;t++)n[t]=e[t];return n}function I(e,r){var t=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(t!=null){var n=[],a=!0,o=!1,i,l;try{for(t=t.call(e);!(a=(i=t.next()).done)&&(n.push(i.value),!(r&&n.length===r));a=!0);}catch(u){o=!0,l=u}finally{try{!a&&t.return!=null&&t.return()}finally{if(o)throw l}}return n}}function E(e){if(Array.isArray(e))return e}function L(e,r){var t=b(),n=S(t,2),a=n[1],o=e.title,i=o===void 0?"Delete Alt":o,l=e.size,u=e.color,v=e.overrides,s=v===void 0?{}:v,y=O(e,_),p=g({component:a.icons&&a.icons.DeleteAlt?a.icons.DeleteAlt:null},s&&s.Svg?m(s.Svg):{});return f.createElement(h,c({viewBox:"0 0 24 24",ref:r,title:i,size:l,color:u,overrides:{Svg:p}},y),f.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M12 20C16.4183 20 20 16.4183 20 12C20 7.58173 16.4183 4 12 4C7.58173 4 4 7.58173 4 12C4 16.4183 7.58173 20 12 20ZM10.0303 8.96967C9.73743 8.67679 9.26257 8.67679 8.96967 8.96967C8.67676 9.26257 8.67676 9.73743 8.96967 10.0303L10.9393 12L8.96967 13.9697C8.67676 14.2626 8.67676 14.7374 8.96967 15.0303C9.26257 15.3232 9.73743 15.3232 10.0303 15.0303L12 13.0607L13.9697 15.0303C14.2626 15.3232 14.7374 15.3232 15.0303 15.0303C15.3232 14.7374 15.3232 14.2626 15.0303 13.9697L13.0607 12L15.0303 10.0303C15.3232 9.73743 15.3232 9.26257 15.0303 8.96967C14.7374 8.67679 14.2626 8.67679 13.9697 8.96967L12 10.9393L10.0303 8.96967Z"}))}const x=f.forwardRef(L);var P={textarea:"textarea"},T={none:"none",left:"left",right:"right",both:"both"},D={mini:"mini",default:"default",compact:"compact",large:"large"},N={start:"start",end:"end"};export{T as A,P as C,x as D,N as E,D as S};
