import{f as e,L as l}from"./index.RuhrnD1v.js";const s=e("label",{target:"e1kt9bl70"})(({disabled:t,labelVisibility:o,theme:i})=>({fontSize:i.fontSizes.sm,color:t?i.colors.fadedText40:i.colors.bodyText,display:o===l.Collapsed?"none":"flex",visibility:o===l.Hidden?"hidden":"visible",marginBottom:i.spacing.twoXS,height:"auto",minHeight:i.fontSizes.xl,verticalAlign:"middle",flexDirection:"row",alignItems:"center"})),a=e("div",{target:"e1kt9bl71"})({display:"flex",flexDirection:"row",justifyContent:"flex-end",flex:1}),d=e("div",{target:"e1kt9bl72"})(({theme:t})=>({fontSize:t.fontSizes.twoSm,color:t.colors.fadedText60,margin:t.spacing.none,textAlign:"right",position:"absolute",bottom:t.spacing.threeXS,right:`calc(${t.fontSizes.mdLg} * 0.5)`})),r=e("span",{target:"e1kt9bl73"})(({theme:t})=>({marginLeft:t.spacing.xs,position:"relative",display:"flex",flexDirection:"row"}));export{r as S,s as a,a as b,d as c};
