const s="https://discuss.streamlit.io",t="https://docs.streamlit.io/develop/concepts/custom-components",e="https://docs.streamlit.io/knowledge-base/using-streamlit/enable-camera",o="https://docs.streamlit.io/end-users/enable-peripherals";export{t as C,o as E,s as a,e as b};
