import{e as d,j as e,F as n,h as l,k as o}from"./index.RuhrnD1v.js";import{a as u}from"./styled-components.CXqQ-NdV.js";function L({label:a,children:r,disabled:t,labelVisibility:s,htmlFor:i}){return d(a)?e(n,{}):l(u,{"data-testid":"stWidgetLabel",disabled:t,labelVisibility:s,htmlFor:i,children:[e("span",{"aria-hidden":"true",children:e(o,{source:a,allowHTML:!1,isLabel:!0})}),r]})}export{L as W};
